@@ -4,8 +4,8 @@
 #
 # Copyright (c) 2007-2008 Peng Huang <shawn.p.huang@gmail.com>
 # Copyright (c) 2009 Hideaki ABE <abe.sendai@gmail.com>
-# Copyright (c) 2010-2017 Takao Fujiwara <takao.fujiwara1@gmail.com>
-# Copyright (c) 2007-2017 Red Hat, Inc.
+# Copyright (c) 2010-2021 Takao Fujiwara <takao.fujiwara1@gmail.com>
+# Copyright (c) 2007-2019 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -76,7 +76,6 @@ class AnthySetup(object):
         except AttributeError:
             pass
         gettext.bindtextdomain(DOMAINNAME, config.LOCALEDIR)
-        gettext.bind_textdomain_codeset(DOMAINNAME, 'UTF-8')
 
         self.__prefs =  AnthyPrefs()
 
@@ -1247,7 +1246,7 @@ class AnthySetup(object):
         model_combobox = combobox.get_model()
         method = model_combobox[id][1]
         type = user_data
-        section_base = None
+        section = None
         key = input.get_text()
         value = output.get_text()
         left_text = left.get_text()
@@ -1302,7 +1301,7 @@ class AnthySetup(object):
         l, i = tv.get_selection().get_selected()
         type = l[i][0]
         key = l[i][1]
-        section_base = None
+        section = None
         if type == 'romaji':
             section = 'romaji-typing-rule'
         elif type == 'kana':
@@ -1373,6 +1372,7 @@ class AnthySetup(object):
     def on_btn_dict_add_clicked(self, widget):
         file = None
         id = None
+        dlg = None
 
         if Gtk.Buildable.get_name(widget) == 'dict:btn_add':
             dlg = Gtk.FileChooserDialog(title=_("Open Dictionary File"),
@@ -1388,6 +1388,7 @@ class AnthySetup(object):
                      _("_OK"), Gtk.ResponseType.OK)
             dlg.add_buttons(*buttons)
 
+        assert (dlg != None), 'Button name is undefined.'
         vbox = self.__builder.get_object('dict:add_extra_vbox')
         if Gtk.Buildable.get_name(widget) == 'dict:btn_add':
             # Need to init for the second time
@@ -1454,7 +1455,7 @@ class AnthySetup(object):
                                       Gtk.MessageType.ERROR)
             return
         if not path.exists(dict_file[0]):
-            self.__run_message_dialog(_("Your file does not exist: ") + dict_file,
+            self.__run_message_dialog(_("Your file does not exist: ") + dict_file[0],
                                       Gtk.MessageType.ERROR)
             return
 
